@@ -2,15 +2,13 @@
 #
 # SPDX-License-Identifier: MIT
 
-import os
-
 from flask import Blueprint
 
 
 def system_blueprint(
     url_prefix: str = '/system',
     env_map: dict[str, str] = {'environment': 'ENVIRONMENT'},
-    env_vars: dict[str, str] = os.environ
+    env_vars: dict[str, str] = {}
 ) -> Blueprint:
     """
     A flask Blueprint that groups system endpoints.
