@@ -81,7 +81,8 @@ class GoatApiClient:
                       'echabs92,habreg_2017,marhabreg-2017,waca_1981,isb_wildlife_act_1976,'
                       'protection_of_badgers_act_1992,family_representative,long_list,'
                       'sample_collected',
-            'ranks': 'subspecies,species,genus,family,order,class,phylum,kingdom,superkingdom'
+            'ranks': 'subspecies,species,genus,family,superfamily,order,class,phylum,kingdom,'
+                     'superkingdom'
         } | self.__get_sort_params(sort_by) | self.__get_page_params(page, page_size)
         return url, params
 
